==> haskell-blaze-html-0.9.1.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-html
version: 0.9.1.1
id: blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
key: blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
license: BSD-3-Clause
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt, Simon Meier
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
abi: 0a8e2e475127588e7a3c82befc314d85
exposed: True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes
import-dirs: /usr/lib/ghc-8.6.5/site-local/blaze-html-0.9.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/blaze-html-0.9.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/blaze-html-0.9.1.1
hs-libraries: HSblaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html: /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-html-0.9.1.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-html
version: 0.9.1.2
id: blaze-html-0.9.1.2-LFnllGMPezqEutot32d3pA
key: blaze-html-0.9.1.2-LFnllGMPezqEutot32d3pA
license: BSD-3-Clause
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt, Simon Meier
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
abi: 048f7e3b8c18d9868a9da3bdaf76b802
exposed: True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes
import-dirs: /usr/lib/ghc-8.6.5/site-local/blaze-html-0.9.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/blaze-html-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/blaze-html-0.9.1.2
hs-libraries: HSblaze-html-0.9.1.2-LFnllGMPezqEutot32d3pA
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html: /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
